@@ -96,25 +96,43 @@ class YahtzeeSinglePlayerV1:
         """
         # 1 -> 6
         if action >= 13 and action <= 18:
-            return self.ytz.c_player.t_scorecard[action - 13][0] / \
-                self.ytz.c_player.t_scorecard[action - 13][1].count(1)
+            try:
+                return self.ytz.c_player.t_scorecard[action - 13][0] / \
+                    self.ytz.c_player.t_scorecard[action - 13][1].count(1)
+            except ZeroDivisionError:
+                return 0
         # 3/4 of a Kind
         elif action == 19 or action == 20:
-            return sum(self.ytz.c_player.dice) / \
-                self.ytz.c_player.t_scorecard[action - 13][1].count(1)
+            try:
+                return sum(self.ytz.c_player.dice) / \
+                    self.ytz.c_player.t_scorecard[action - 13][1].count(1)
+            except ZeroDivisionError:
+                return 0
         # Full House
         elif action == 21:
-            return 25 / self.ytz.c_player.t_scorecard[action - 13][1].count(1)
+            try:
+                return 25 / self.ytz.c_player.t_scorecard[action - 13][1].count(1)
+            except ZeroDivisionError:
+                return 0
         # Small Straight
         elif action == 22:
-            return 30 / self.ytz.c_player.t_scorecard[action - 13][1].count(1)
+            try:
+                return 30 / self.ytz.c_player.t_scorecard[action - 13][1].count(1)
+            except ZeroDivisionError:
+                return 0
         # Large Straight
         elif action == 23:
-            return 40 / self.ytz.c_player.t_scorecard[action - 13][1].count(1)
+            try:
+                return 40 / self.ytz.c_player.t_scorecard[action - 13][1].count(1)
+            except ZeroDivisionError:
+                return 0
         # Chance
         elif action == 24:
             return 12 if sum(self.dice) <= 12 else 3
         # Yahtzee
         else:
-            return 50 * self.ytz.c_player.t_scorecard[action - 13][1].count(1)
+            try:
+                return 50 / self.ytz.c_player.t_scorecard[action - 13][1].count(1)
+            except ZeroDivisionError:
+                return 0
         
\ No newline at end of file
